@@ -18,14 +18,15 @@ class SensorsFeatureSensor;
 class LinuxCpuObject : public CpuObject
 {
 public:
-    LinuxCpuObject(const QString &id, const QString &name, KSysGuard::SensorContainer *parent);
+    LinuxCpuObject(const QString &id, const QString &name, double initialFrequency, KSysGuard::SensorContainer *parent);
 
     void update(unsigned long long system, unsigned long long user, unsigned long long wait, unsigned long long idle);
-    void initialize(double initialFrequency);
+    void initialize() override;
     void makeTemperatureSensor(const sensors_chip_name * constchipName, const sensors_feature * const feature);
 private:
-    void initialize() override {};
     void makeSensors() override;
+
+    double m_initialFrequency;
     UsageComputer m_usageComputer;
 };
 
