@@ -6,9 +6,9 @@
 
 #pragma once
 
-#include <memory>
 #include <QObject>
 #include <QProcess>
+#include <memory>
 
 class NvidiaSmiProcess : public QObject
 {
@@ -26,11 +26,13 @@ public:
     };
 
     struct GpuQueryResult {
+        QString pciPath;
         QString name;
         uint totalMemory = 0;
         uint maxCoreFrequency = 0;
         uint maxMemoryFrequency = 0;
         uint maxTemperature = 0;
+        uint maxPower = 0;
     };
 
     NvidiaSmiProcess();
